chaincode

package
v0.0.0-...-f8a1501 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 4, 2021 License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type SmartContract

type SmartContract struct {
	contractapi.Contract
}

SmartContract todo

func (*SmartContract) CreateVA

func (s *SmartContract) CreateVA(ctx contractapi.TransactionContextInterface, id string, issuer string, owner string, amount int64, contractHash string, invoiceHash string) error

CreateVA create voucher asset

func (*SmartContract) DeleteVA

DeleteVA todo delete voucher asset

func (*SmartContract) ExistsVA

ExistsVA todo

func (*SmartContract) GetAllVA

GetAllVA returns all voucher assets found in world state

func (*SmartContract) InitLedger

InitLedger todo

type VoucherAsset

type VoucherAsset struct {
	ID           string    `json:"ID"`
	ParentID     string    `json:"parentID"`
	Issuer       string    `json:"issuer"`
	Owner        string    `json:"owner"`
	Amount       int64     `json:"amount"`
	CreateDate   time.Time `json:"createDate"`
	EndDate      time.Time `json:"endDate"`
	ContractHash string    `json:"contractHash"`
	InvoiceHash  string    `json:"invoiceHash"`
	Status       string    `json:"status"`
	Signature    string    `json:"signature"`
}

VoucherAsset voucher assets

Jump to